==> me-tv_0.7.16.orig.tar.gz: me-tv-0.7.16/src/me-tv-ui.h <==
/*
 * Copyright (C) 2009 Michael Lamothe
 *
 * This file is part of Me TV
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor Boston, MA 02110-1301,  USA
 */

#ifndef __ME_TV_UI_H__
#define __ME_TV_UI_H__

#include <libgnomeuimm.h>
#include <libglademm.h>
#include "me-tv.h"
#include "dvb_frontend.h"
#include "channel.h"

class ComboBoxText : public Gtk::ComboBoxText
{
public:
	ComboBoxText(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& xml);
};

class ComboBoxEntryText : public Gtk::ComboBoxEntryText
{
public:
	ComboBoxEntryText(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& xml);
};

class ChannelComboBox : public Gtk::ComboBox
{
private:
	class ModelColumns : public Gtk::TreeModel::ColumnRecord
	{
	public:
		ModelColumns()
		{
			add(column_id);
			add(column_name);
		}

		Gtk::TreeModelColumn<guint>			column_id;
		Gtk::TreeModelColumn<Glib::ustring>	column_name;
	};
	
	ModelColumns columns;
	Glib::RefPtr<Gtk::ListStore> list_store;
		
public:
	ChannelComboBox(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& xml);
	void load(const ChannelList& channels);
	guint get_selected_channel_id();
	void set_selected_channel_id(guint channel_id);
};

class GdkLock
{
public:
	GdkLock();
	~GdkLock();
};

class GdkUnlock
{
public:
	GdkUnlock();
	~GdkUnlock();
};

#endif

==> me-tv_1.0.0.orig.tar.gz: me-tv-1.0.0/src/me-tv-ui.h <==
/*
 * Copyright (C) 2009 Michael Lamothe
 *
 * This file is part of Me TV
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor Boston, MA 02110-1301,  USA
 */

#ifndef __ME_TV_UI_H__
#define __ME_TV_UI_H__

#include <libgnomeuimm.h>
#include "me-tv.h"
#include "dvb_frontend.h"
#include "channel.h"


// This class exists because I can't get Gtk::ComboBoxText to work properly
// it seems to have 2 columns
class ComboBoxText : public Gtk::ComboBox
{
private:
	class ModelColumns : public Gtk::TreeModel::ColumnRecord
	{
	public:
		ModelColumns()
		{
			add(column_string);
		}

		Gtk::TreeModelColumn<Glib::ustring> column_string;
	};
	
	ModelColumns columns;
	Glib::RefPtr<Gtk::ListStore> list_store;
	
public:
	ComboBoxText(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& xml);
	
	void clear_items();
	void append(const Glib::ustring& text);
	void set_text(const Glib::ustring& text);
	Glib::ustring get_text();
};

class IntComboBox : public Gtk::ComboBox
{
private:
	class ModelColumns : public Gtk::TreeModel::ColumnRecord
	{
	public:
		ModelColumns()
		{
			add(column_int);
		}

		Gtk::TreeModelColumn<guint> column_int;
	};
	
	ModelColumns columns;
	Glib::RefPtr<Gtk::ListStore> list_store;
		
public:
	IntComboBox(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& xml);
	void set_size(guint size);
	guint get_size();
	guint get_active_value();
};

class ComboBoxEntryText : public Gtk::ComboBoxEntryText
{
public:
	ComboBoxEntryText(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& xml);
};

class ChannelComboBox : public Gtk::ComboBox
{
private:
	class ModelColumns : public Gtk::TreeModel::ColumnRecord
	{
	public:
		ModelColumns()
		{
			add(column_id);
			add(column_name);
		}

		Gtk::TreeModelColumn<guint>			column_id;
		Gtk::TreeModelColumn<Glib::ustring>	column_name;
	};
	
	ModelColumns columns;
	Glib::RefPtr<Gtk::ListStore> list_store;
		
public:
	ChannelComboBox(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& xml);
	void load(const ChannelArray& channels);
	guint get_selected_channel_id();
	void set_selected_channel_id(guint channel_id);
};

class GdkLock
{
public:
	GdkLock();
	~GdkLock();
};

class GdkUnlock
{
public:
	GdkUnlock();
	~GdkUnlock();
};

class FullscreenBugWorkaround
{
private:
	gboolean apply;
public:
	FullscreenBugWorkaround();
	~FullscreenBugWorkaround();
};

#endif
